@@ -3,16 +3,17 @@
 ADB Debugging must be enabled.
 """
 
-from .androidtv import AndroidTV
-from .basetv import BaseTV, state_detection_rules_validator
+from .androidtv.androidtv_sync import AndroidTVSync
+from .basetv.basetv import state_detection_rules_validator
+from .basetv.basetv_sync import BaseTVSync
 from .constants import DEFAULT_AUTH_TIMEOUT_S
-from .firetv import FireTV
+from .firetv.firetv_sync import FireTVSync
 
 
-__version__ = '0.0.44'
+__version__ = '0.0.45'
 
 
-def setup(host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, state_detection_rules=None, device_class='auto', auth_timeout_s=DEFAULT_AUTH_TIMEOUT_S):
+def setup(host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, state_detection_rules=None, device_class='auto', auth_timeout_s=DEFAULT_AUTH_TIMEOUT_S, signer=None):
     """Connect to a device and determine whether it's an Android TV or an Amazon Fire TV.
 
     Parameters
@@ -28,26 +29,28 @@ def setup(host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, st
     adb_server_port : int
         The port for the ADB server
     state_detection_rules : dict, None
-        A dictionary of rules for determining the state (see :class:`~androidtv.basetv.BaseTV`)
+        A dictionary of rules for determining the state (see :class:`~androidtv.basetv.basetv.BaseTV`)
     device_class : str
         The type of device: ``'auto'`` (detect whether it is an Android TV or Fire TV device), ``'androidtv'``, or ``'firetv'```
     auth_timeout_s : float
         Authentication timeout (in seconds)
+    signer : PythonRSASigner, None
+        The signer for the ADB keys, as loaded by :meth:`androidtv.adb_manager.adb_manager_sync.ADBPythonSync.load_adbkey`
 
     Returns
     -------
-    aftv : AndroidTV, FireTV
+    AndroidTVSync, FireTVSync
         The representation of the device
 
     """
     if device_class == 'androidtv':
-        atv = AndroidTV(host, port, adbkey, adb_server_ip, adb_server_port, state_detection_rules)
+        atv = AndroidTVSync(host, port, adbkey, adb_server_ip, adb_server_port, state_detection_rules, signer)
         atv.adb_connect(auth_timeout_s=auth_timeout_s)
         atv.device_properties = atv.get_device_properties()
         return atv
 
     if device_class == 'firetv':
-        ftv = FireTV(host, port, adbkey, adb_server_ip, adb_server_port, state_detection_rules)
+        ftv = FireTVSync(host, port, adbkey, adb_server_ip, adb_server_port, state_detection_rules, signer)
         ftv.adb_connect(auth_timeout_s=auth_timeout_s)
         ftv.device_properties = ftv.get_device_properties()
         return ftv
@@ -55,7 +58,7 @@ def setup(host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, st
     if device_class != 'auto':
         raise ValueError("`device_class` must be 'androidtv', 'firetv', or 'auto'.")
 
-    aftv = BaseTV(host, port, adbkey, adb_server_ip, adb_server_port, state_detection_rules)
+    aftv = BaseTVSync(host, port, adbkey, adb_server_ip, adb_server_port, state_detection_rules, signer)
 
     # establish the ADB connection
     aftv.adb_connect(auth_timeout_s=auth_timeout_s)
@@ -65,11 +68,11 @@ def setup(host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, st
 
     # Fire TV
     if aftv.device_properties.get('manufacturer') == 'Amazon':
-        aftv.__class__ = FireTV
+        aftv.__class__ = FireTVSync
 
     # Android TV
     else:
-        aftv.__class__ = AndroidTV
+        aftv.__class__ = AndroidTVSync
 
     return aftv
 
@@ -77,7 +80,7 @@ def setup(host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, st
 def ha_state_detection_rules_validator(exc):
     """Validate the rules (i.e., the ``state_detection_rules`` value) for a given app ID (i.e., a key in ``state_detection_rules``).
 
-    See :class:`~androidtv.basetv.BaseTV` for more info about the ``state_detection_rules`` parameter.
+    See :class:`~androidtv.basetv.basetv.BaseTV` for more info about the ``state_detection_rules`` parameter.
 
     Parameters
     ----------
